@@ -99,11 +99,17 @@ enum option_type {
   TYPE_UNIX_ERROR = 4
 };
 
-extern value unix_getsockopt_aux(
+#include <caml/version.h>
+#if OCAML_VERSION_MAJOR < 5
+#define caml_unix_getsockopt_aux unix_getsockopt_aux
+#define caml_unix_setsockopt_aux unix_setsockopt_aux
+#endif
+
+extern value caml_unix_getsockopt_aux(
   char *name,
   enum option_type ty, int level, int option,
   value v_socket);
-extern value unix_setsockopt_aux(
+extern value caml_unix_setsockopt_aux(
   char *name,
   enum option_type ty, int level, int option,
   value v_socket, value v_status);
@@ -112,7 +118,7 @@ CAMLprim value core_linux_gettcpopt_bool_stub(value v_socket, value v_option)
 {
   int option = linux_tcpopt_bool[Int_val(v_option)];
   return
-    unix_getsockopt_aux("getsockopt", TYPE_BOOL, SOL_TCP, option, v_socket);
+    caml_unix_getsockopt_aux("getsockopt", TYPE_BOOL, SOL_TCP, option, v_socket);
 }
 
 CAMLprim value
@@ -120,7 +126,7 @@ core_linux_settcpopt_bool_stub(value v_socket, value v_option, value v_status)
 {
   int option = linux_tcpopt_bool[Int_val(v_option)];
   return
-    unix_setsockopt_aux(
+    caml_unix_setsockopt_aux(
       "setsockopt", TYPE_BOOL, SOL_TCP, option, v_socket, v_status);
 }
 
@@ -798,6 +804,6 @@ CAMLprim value core_linux_setxattr(value v_path, value v_name, value v_value, va
 
 #else
 
-typedef int avoid_empty_translation_unit_compilation_error;
+void avoid_empty_translation_unit_compilation_error_in_core_unix_linux_ext(void) {}
 
 #endif /* JSC_LINUX_EXT */
